Index: /CKEditor/trunk/CHANGES.html
===================================================================
--- /CKEditor/trunk/CHANGES.html	(revision 7498)
+++ /CKEditor/trunk/CHANGES.html	(revision 7499)
@@ -1,3 +1,3 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+﻿<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <!--
 Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
@@ -50,4 +50,5 @@
 		<li><a href="http://dev.ckeditor.com/ticket/9008">#9008</a> : Fixed list items order reversed when merging two lists.</li>
 		<li><a href="http://dev.ckeditor.com/ticket/9042">#9042</a> : [Safari] Fixed pasting left garbage html at the end of document.</li>
+		<li><a href="http://dev.ckeditor.com/ticket/7745">#7745</a> : The list of frames on JAWS will not any more show the "ALT+0 for help" text for the editor entry.</li>
 	</ul>
 	<h3>
Index: /CKEditor/trunk/_source/lang/_translationstatus.txt
===================================================================
--- /CKEditor/trunk/_source/lang/_translationstatus.txt	(revision 7498)
+++ /CKEditor/trunk/_source/lang/_translationstatus.txt	(revision 7499)
@@ -2,63 +2,63 @@
 For licensing, see LICENSE.html or http://ckeditor.com/license
 
-af.js      Found: 549 Missing: 27
-ar.js      Found: 470 Missing: 106
-bg.js      Found: 394 Missing: 182
-bn.js      Found: 292 Missing: 284
-bs.js      Found: 175 Missing: 401
-ca.js      Found: 550 Missing: 26
-cs.js      Found: 576 Missing: 0
-cy.js      Found: 576 Missing: 0
-da.js      Found: 576 Missing: 0
-de.js      Found: 576 Missing: 0
-el.js      Found: 391 Missing: 185
-en-au.js   Found: 348 Missing: 228
-en-ca.js   Found: 345 Missing: 231
-en-gb.js   Found: 518 Missing: 58
-eo.js      Found: 576 Missing: 0
-es.js      Found: 576 Missing: 0
-et.js      Found: 576 Missing: 0
-eu.js      Found: 417 Missing: 159
-fa.js      Found: 576 Missing: 0
-fi.js      Found: 576 Missing: 0
-fo.js      Found: 576 Missing: 0
-fr-ca.js   Found: 319 Missing: 257
-fr.js      Found: 576 Missing: 0
-gl.js      Found: 292 Missing: 284
-gu.js      Found: 576 Missing: 0
-he.js      Found: 576 Missing: 0
-hi.js      Found: 328 Missing: 248
-hr.js      Found: 576 Missing: 0
-hu.js      Found: 573 Missing: 3
-id.js      Found: 1 Missing: 575
-is.js      Found: 326 Missing: 250
-it.js      Found: 576 Missing: 0
-ja.js      Found: 494 Missing: 82
-ka.js      Found: 569 Missing: 7
-km.js      Found: 286 Missing: 290
-ko.js      Found: 304 Missing: 272
-lt.js      Found: 576 Missing: 0
-lv.js      Found: 294 Missing: 282
-mk.js      Found: 1 Missing: 575
-mn.js      Found: 320 Missing: 256
-ms.js      Found: 276 Missing: 300
-nb.js      Found: 576 Missing: 0
-nl.js      Found: 576 Missing: 0
-no.js      Found: 576 Missing: 0
-pl.js      Found: 576 Missing: 0
-pt-br.js   Found: 576 Missing: 0
-pt.js      Found: 326 Missing: 250
-ro.js      Found: 433 Missing: 143
-ru.js      Found: 576 Missing: 0
-sk.js      Found: 365 Missing: 211
-sl.js      Found: 426 Missing: 150
-sr-latn.js Found: 287 Missing: 289
-sr.js      Found: 286 Missing: 290
-sv.js      Found: 551 Missing: 25
-th.js      Found: 298 Missing: 278
-tr.js      Found: 576 Missing: 0
-ug.js      Found: 573 Missing: 3
-uk.js      Found: 576 Missing: 0
-vi.js      Found: 576 Missing: 0
-zh-cn.js   Found: 576 Missing: 0
-zh.js      Found: 434 Missing: 142
+af.js      Found: 548 Missing: 29
+ar.js      Found: 470 Missing: 107
+bg.js      Found: 393 Missing: 184
+bn.js      Found: 292 Missing: 285
+bs.js      Found: 175 Missing: 402
+ca.js      Found: 549 Missing: 28
+cs.js      Found: 575 Missing: 2
+cy.js      Found: 575 Missing: 2
+da.js      Found: 575 Missing: 2
+de.js      Found: 575 Missing: 2
+el.js      Found: 391 Missing: 186
+en-au.js   Found: 347 Missing: 230
+en-ca.js   Found: 345 Missing: 232
+en-gb.js   Found: 517 Missing: 60
+eo.js      Found: 575 Missing: 2
+es.js      Found: 575 Missing: 2
+et.js      Found: 575 Missing: 2
+eu.js      Found: 417 Missing: 160
+fa.js      Found: 575 Missing: 2
+fi.js      Found: 575 Missing: 2
+fo.js      Found: 575 Missing: 2
+fr-ca.js   Found: 319 Missing: 258
+fr.js      Found: 575 Missing: 2
+gl.js      Found: 292 Missing: 285
+gu.js      Found: 575 Missing: 2
+he.js      Found: 575 Missing: 2
+hi.js      Found: 327 Missing: 250
+hr.js      Found: 575 Missing: 2
+hu.js      Found: 572 Missing: 5
+id.js      Found: 1 Missing: 576
+is.js      Found: 326 Missing: 251
+it.js      Found: 575 Missing: 2
+ja.js      Found: 493 Missing: 84
+ka.js      Found: 568 Missing: 9
+km.js      Found: 286 Missing: 291
+ko.js      Found: 304 Missing: 273
+lt.js      Found: 575 Missing: 2
+lv.js      Found: 294 Missing: 283
+mk.js      Found: 0 Missing: 577
+mn.js      Found: 320 Missing: 257
+ms.js      Found: 276 Missing: 301
+nb.js      Found: 575 Missing: 2
+nl.js      Found: 575 Missing: 2
+no.js      Found: 575 Missing: 2
+pl.js      Found: 575 Missing: 2
+pt-br.js   Found: 575 Missing: 2
+pt.js      Found: 326 Missing: 251
+ro.js      Found: 432 Missing: 145
+ru.js      Found: 575 Missing: 2
+sk.js      Found: 364 Missing: 213
+sl.js      Found: 426 Missing: 151
+sr-latn.js Found: 287 Missing: 290
+sr.js      Found: 286 Missing: 291
+sv.js      Found: 550 Missing: 27
+th.js      Found: 298 Missing: 279
+tr.js      Found: 575 Missing: 2
+ug.js      Found: 572 Missing: 5
+uk.js      Found: 575 Missing: 2
+vi.js      Found: 575 Missing: 2
+zh-cn.js   Found: 575 Missing: 2
+zh.js      Found: 433 Missing: 144
Index: /CKEditor/trunk/_source/lang/af.js
===================================================================
--- /CKEditor/trunk/_source/lang/af.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/af.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Teksverwerker, %1, druk op ALT 0 vir hulp.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ar.js
===================================================================
--- /CKEditor/trunk/_source/lang/ar.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ar.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/bg.js
===================================================================
--- /CKEditor/trunk/_source/lang/bg.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/bg.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Текстов редактор за форматиран текст, %1, натиснете ALT 0 за помощ.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/bn.js
===================================================================
--- /CKEditor/trunk/_source/lang/bn.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/bn.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/bs.js
===================================================================
--- /CKEditor/trunk/_source/lang/bs.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/bs.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ca.js
===================================================================
--- /CKEditor/trunk/_source/lang/ca.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ca.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Editor de text enriquit, %1, prem ALT 0 per obtenir ajuda.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/cs.js
===================================================================
--- /CKEditor/trunk/_source/lang/cs.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/cs.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Textový editor, %1, nápovědu zobrazíte stiskem ALT 0.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/cy.js
===================================================================
--- /CKEditor/trunk/_source/lang/cy.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/cy.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Golygydd testun cyfoethog, %1, gwasgwch ALT 0 am gymorth.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/da.js
===================================================================
--- /CKEditor/trunk/_source/lang/da.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/da.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich Text Editor, %1, tryk ALT 0 for hjælp.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/de.js
===================================================================
--- /CKEditor/trunk/_source/lang/de.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/de.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'WYSIWYG-Editor, %1, drücken Sie ALT 0 für Hilfe.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/el.js
===================================================================
--- /CKEditor/trunk/_source/lang/el.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/el.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/en-au.js
===================================================================
--- /CKEditor/trunk/_source/lang/en-au.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/en-au.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/en-ca.js
===================================================================
--- /CKEditor/trunk/_source/lang/en-ca.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/en-ca.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/en-gb.js
===================================================================
--- /CKEditor/trunk/_source/lang/en-gb.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/en-gb.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/en.js
===================================================================
--- /CKEditor/trunk/_source/lang/en.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/en.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.',
+	editorTitle : 'Rich text editor, %1',
+	editorHelp : 'Press ALT 0 for help',
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/eo.js
===================================================================
--- /CKEditor/trunk/_source/lang/eo.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/eo.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Redaktilo por Riĉiga Teksto, %1, premu ALT 0 por helpo.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/es.js
===================================================================
--- /CKEditor/trunk/_source/lang/es.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/es.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Editor de texto, %1, pulse ALT 0 para ayuda.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/et.js
===================================================================
--- /CKEditor/trunk/_source/lang/et.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/et.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rikkalik tekstiredaktor %1, abi jaoks vajuta ALT 0.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/eu.js
===================================================================
--- /CKEditor/trunk/_source/lang/eu.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/eu.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/fa.js
===================================================================
--- /CKEditor/trunk/_source/lang/fa.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/fa.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'ویرایشگر متن غنی, %1, کلید Alt+0 را برای راهنمایی بفشارید.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/fi.js
===================================================================
--- /CKEditor/trunk/_source/lang/fi.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/fi.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rikastekstieditori, %1, paina ALT 0 nähdäksesi ohjeen.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/fo.js
===================================================================
--- /CKEditor/trunk/_source/lang/fo.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/fo.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, trýst ALT og 0 fyri vegleiðing.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/fr-ca.js
===================================================================
--- /CKEditor/trunk/_source/lang/fr-ca.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/fr-ca.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/fr.js
===================================================================
--- /CKEditor/trunk/_source/lang/fr.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/fr.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Éditeur de Texte Enrichi, %1, appuyez sur ALT-0 pour l\'aide.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/gl.js
===================================================================
--- /CKEditor/trunk/_source/lang/gl.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/gl.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/gu.js
===================================================================
--- /CKEditor/trunk/_source/lang/gu.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/gu.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'રીચ ટેક્ષ્ત્ એડિટર, %1, પ્રેસ ALT 0 મદદ માટે.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/he.js
===================================================================
--- /CKEditor/trunk/_source/lang/he.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/he.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'עורך טקסט עשיר, %1, לחץ אלט (ALT) + 0 לעזרה.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/hi.js
===================================================================
--- /CKEditor/trunk/_source/lang/hi.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/hi.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'रिच टेक्स्ट एडिटर, %1, मदद के लिये ALT 0 दबाए.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/hr.js
===================================================================
--- /CKEditor/trunk/_source/lang/hr.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/hr.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Bogati uređivač teksta, %1, pritisni ALT 0 za pomoć.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/hu.js
===================================================================
--- /CKEditor/trunk/_source/lang/hu.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/hu.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'HTML szerkesztő',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/id.js
===================================================================
--- /CKEditor/trunk/_source/lang/id.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/id.js	(revision 7499)
@@ -31,5 +31,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/is.js
===================================================================
--- /CKEditor/trunk/_source/lang/is.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/is.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/it.js
===================================================================
--- /CKEditor/trunk/_source/lang/it.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/it.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, premere ALT 0 per l\'help in linea.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ja.js
===================================================================
--- /CKEditor/trunk/_source/lang/ja.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ja.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'リッチテキストエディタ, %1, ヘルプは ALT 0 を押してください',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ka.js
===================================================================
--- /CKEditor/trunk/_source/lang/ka.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ka.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'ტექსტის რედაქტორი, %1, დააჭირეთ ALT 0-ს დახმარების მისაღებად.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/km.js
===================================================================
--- /CKEditor/trunk/_source/lang/km.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/km.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ko.js
===================================================================
--- /CKEditor/trunk/_source/lang/ko.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ko.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/lt.js
===================================================================
--- /CKEditor/trunk/_source/lang/lt.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/lt.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Pilnas redaktorius, %1, spauskite ALT 0 dėl pagalbos.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/lv.js
===================================================================
--- /CKEditor/trunk/_source/lang/lv.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/lv.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/mk.js
===================================================================
--- /CKEditor/trunk/_source/lang/mk.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/mk.js	(revision 7499)
@@ -31,5 +31,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Богат уредувач на текст, %1, притисни ALТ 0 за помош.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/mn.js
===================================================================
--- /CKEditor/trunk/_source/lang/mn.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/mn.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ms.js
===================================================================
--- /CKEditor/trunk/_source/lang/ms.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ms.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/nb.js
===================================================================
--- /CKEditor/trunk/_source/lang/nb.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/nb.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rikteksteditor, %1, trykk ALT 0 for hjelp.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/nl.js
===================================================================
--- /CKEditor/trunk/_source/lang/nl.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/nl.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Tekstverwerker, %1, druk op ALT 0 voor hulp.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/no.js
===================================================================
--- /CKEditor/trunk/_source/lang/no.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/no.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rikteksteditor, %1, trykk ALT 0 for hjelp.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/pl.js
===================================================================
--- /CKEditor/trunk/_source/lang/pl.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/pl.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Edytor tekstu sformatowanego, %1, w celu uzyskania pomocy naciśnij ALT 0.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/pt-br.js
===================================================================
--- /CKEditor/trunk/_source/lang/pt-br.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/pt-br.js	(revision 7499)
@@ -31,5 +31,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Editor de Texto, %1, pressione ALT 0 para obter ajuda.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/pt.js
===================================================================
--- /CKEditor/trunk/_source/lang/pt.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/pt.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ro.js
===================================================================
--- /CKEditor/trunk/_source/lang/ro.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ro.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, apasă ALT 0 pentru ajutor.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ru.js
===================================================================
--- /CKEditor/trunk/_source/lang/ru.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ru.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Визуальный редактор текста, %1, нажмите ALT-0 для открытия справки.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/sk.js
===================================================================
--- /CKEditor/trunk/_source/lang/sk.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/sk.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, stlačte ALT 0 pre nápovedu.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/sl.js
===================================================================
--- /CKEditor/trunk/_source/lang/sl.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/sl.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/sr-latn.js
===================================================================
--- /CKEditor/trunk/_source/lang/sr-latn.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/sr-latn.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/sr.js
===================================================================
--- /CKEditor/trunk/_source/lang/sr.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/sr.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/sv.js
===================================================================
--- /CKEditor/trunk/_source/lang/sv.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/sv.js	(revision 7499)
@@ -31,5 +31,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, tryck ALT 0 för hjälp.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/th.js
===================================================================
--- /CKEditor/trunk/_source/lang/th.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/th.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/tr.js
===================================================================
--- /CKEditor/trunk/_source/lang/tr.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/tr.js	(revision 7499)
@@ -31,5 +31,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Zengin metin editörü, %1, yardım için ALT 0 tuşuna basın.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/ug.js
===================================================================
--- /CKEditor/trunk/_source/lang/ug.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/ug.js	(revision 7499)
@@ -31,5 +31,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'كۆرۈنۈشچان تەھرىرلىگۈچ، %1، ALT+0 نى بېسىپ ياردەمنى كۆرۈڭ.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/uk.js
===================================================================
--- /CKEditor/trunk/_source/lang/uk.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/uk.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Текстовий редактор, %1, натисніть ALT 0 для довідки.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/vi.js
===================================================================
--- /CKEditor/trunk/_source/lang/vi.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/vi.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Bộ soạn thảo, %1, nhấn ALT + 0 để xem hướng dẫn.',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/zh-cn.js
===================================================================
--- /CKEditor/trunk/_source/lang/zh-cn.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/zh-cn.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : '所见即所得编辑器, %1, 按 ALT+0 查看帮助。',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/lang/zh.js
===================================================================
--- /CKEditor/trunk/_source/lang/zh.js	(revision 7498)
+++ /CKEditor/trunk/_source/lang/zh.js	(revision 7499)
@@ -32,5 +32,6 @@
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : '富文本編輯器，%1，按 ALT+0 以獲得幫助。',
+	editorTitle : 'Rich text editor, %1', // MISSING
+	editorHelp : 'Press ALT 0 for help', // MISSING
 
 	// ARIA descriptions.
Index: /CKEditor/trunk/_source/plugins/wysiwygarea/plugin.js
===================================================================
--- /CKEditor/trunk/_source/plugins/wysiwygarea/plugin.js	(revision 7498)
+++ /CKEditor/trunk/_source/plugins/wysiwygarea/plugin.js	(revision 7499)
@@ -477,5 +477,9 @@
 				? editor.config.enterMode == CKEDITOR.ENTER_DIV ? 'div' : 'p' : false;
 
-			var frameLabel = editor.lang.editorTitle.replace( '%1', editor.name );
+			var frameLabel = editor.lang.editorTitle.replace( '%1', editor.name ),
+				frameDesc = editor.lang.editorHelp;
+
+			if ( CKEDITOR.env.ie )
+				frameLabel += ', ' + frameDesc;
 
 			var win = CKEDITOR.document.getWindow();
@@ -521,8 +525,10 @@
 								'';
 
+						var labelId = CKEDITOR.tools.getNextId();
 						iframe = CKEDITOR.dom.element.createFromHtml( '<iframe' +
   							' style="width:100%;height:100%"' +
   							' frameBorder="0"' +
-  							' title="' + frameLabel + '"' +
+  							' aria-describedby="' + labelId + '"' +
+							' title="' + frameLabel + '"' +
   							' src="' + src + '"' +
 							' tabIndex="' + ( CKEDITOR.env.webkit? -1 : editor.tabIndex ) + '"' +
@@ -549,4 +555,7 @@
 						if ( document.location.protocol == 'chrome:' )
 							CKEDITOR.event.useCapture = false;
+
+						mainElement.append( CKEDITOR.dom.element.createFromHtml(
+							'<span id="' + labelId + '" class="cke_voice_label">' + frameDesc + '</span>'));
 
 						mainElement.append( iframe );
@@ -1152,8 +1161,8 @@
 				});
 
-			var titleBackup;
-			// Setting voice label as window title, backup the original one
-			// and restore it before running into use.
-			editor.on( 'contentDom', function()
+			// [IE] JAWS will not recognize the aria label we used on the iframe
+			// unless the frame window title string is used as the voice label,
+			// backup the original one and restore it on output.
+			CKEDITOR.env.ie && editor.on( 'contentDom', function()
 				{
 					var title = editor.document.getElementsByTag( 'title' ).getItem( 0 );
